@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vteskel.c,v 1.9 2003/06/16 21:15:10 nalin Exp $"
+#ident "$Id: vteskel.c,v 1.10 2004/04/20 05:16:56 nalin Exp $"
 
 #include "../config.h"
 
@@ -137,7 +137,8 @@ _vte_skel_clear(struct _vte_draw *draw,
 
 static void
 _vte_skel_set_text_font(struct _vte_draw *draw,
-			const PangoFontDescription *fontdesc)
+			const PangoFontDescription *fontdesc,
+			VteTerminalAntiAlias antialias)
 {
 	struct _vte_skel_data *data;
 	data = (struct _vte_skel_data*) draw->impl_data;
